@@ -38,8 +38,10 @@ class ConfigSpaceHolder(ABC):
 
 
 def config_list_to_array(X: Union[List[CS.Configuration], List[Iterable[float]], np.ndarray]) -> np.ndarray:
-    if isinstance(X, list):
-        if isinstance(X[0], CS.Configuration):
+    if isinstance(X, (tuple, list)):
+        if len(X) == 0:
+            X = []
+        elif isinstance(X[0], CS.Configuration):
             X = [config.get_array() for config in X]
     return np.asarray(X)
 
